@@ -1144,7 +1144,7 @@ if ( ! defined( 'CIVICRM_WPCLI_LOADED' ) ) {
 				$parsed['dbsyntax'] = $str;
 			}
 
-			if ( ! count( $dsn ) ) {
+			if ( empty( $dsn ) ) {
 				return $parsed;
 			}
 
